==> vtigercrm-5.3.0p0.tgz: modules/Rss/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header$
 * Description:  Defines the English language pack for the Account module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese|30/12/2010|Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'RSS',
'LBL_MODULE_TITLE'=>'RSS: Principal',

'LBL_NEW_RSS_ENTRY'=>'URL Novo alimentador Notícias RSS:',
'LBL_SEARCH_RSS'=>'Pesquisar Título:',
'LBL_NEW_RSS_BUTTON'=>'Adicionar',

'LBL_STARRED_RSS'=>'RSS Principais',
'LBL_POP_CRM_RSS'=>'Principais Alimentadores relacionados com CRM',
'LBL_ALL_RSS_FEEDS'=>'Todas os Alimentadores RSS',
'LBL_VTIGER_RSS_READER'=>'Leitor RSS vtiger',

'LBL_MORE'=>'Mais...',
'LBL_SUBJECT'=>'Assunto',
'LBL_SENDER'=>'Remetente',
'LBL_CATEGORY'=>'Categoria :',
'LBL_FEED'=>'Alimentador :',
'LBL_FEED_SOURCES'=>'Fontes Alimentador',
'LBL_ADD_RSS_FEED'=>'Adicionar Alimentador RSS',
'LBL_DELETE_BUTTON'=>'Apagar',
'LBL_SET_DEFAULT_BUTTON'=>'Definir como Padrão',
'LBL_FEEDS_LIST'=>'Lista de Alimentadores de:',
'LBL_ERROR_MSG'=>'Nenhum Alimentador RSS foi selecionado ou suas Configurações Proxy não está adequada',
'LBL_REGRET_MSG'=>'Desculpe: Não é possível acessar a URL do RSS',

'UNABLE_TO_SAVE'=>'Impossível salvar URL do alimentador RSS',

// Added/Updated for vtiger CRM 5.0.4
'NOT_A_VALID'=>'URL inválida para alimentador RSS ou as configurações do seu Proxy não estão corretas',

// Added after 5.0.4 GA
'INVALID_RSS_URL' => 'URL RSS não é válida',
'UNABLE_TO_SAVE' => 'Não é possível salvar a URL',

);
?>

==> vtigercrm-5.4.0.tgz: modules/Rss/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header$
 * Description:  Defines the English language pack for the RSS module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese| 03/03/2012 |Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'RSS',
'LBL_MODULE_TITLE'=>'RSS: Principal',

'LBL_NEW_RSS_ENTRY'=>'URL Novo alimentador Notícias RSS:',
'LBL_SEARCH_RSS'=>'Pesquisar Título:',
'LBL_NEW_RSS_BUTTON'=>'Adicionar',

'LBL_STARRED_RSS'=>'RSS Principais',
'LBL_POP_CRM_RSS'=>'Principais Alimentadores relacionados com CRM',
'LBL_ALL_RSS_FEEDS'=>'Todas os Alimentadores RSS',
'LBL_VTIGER_RSS_READER'=>'Leitor RSS vtiger',

'LBL_MORE'=>'Mais...',
'LBL_SUBJECT'=>'Assunto',
'LBL_SENDER'=>'Remetente',
'LBL_CATEGORY'=>'Categoria :',
'LBL_FEED'=>'Alimentador :',
'LBL_FEED_SOURCES'=>'Fontes Alimentador',
'LBL_ADD_RSS_FEED'=>'Adicionar Alimentador RSS',
'LBL_DELETE_BUTTON'=>'Apagar',
'LBL_SET_DEFAULT_BUTTON'=>'Definir como Padrão',
'LBL_FEEDS_LIST'=>'Lista de Alimentadores de:',
'LBL_ERROR_MSG'=>'Nenhum Alimentador RSS foi selecionado ou suas Configurações Proxy não está adequada',
'LBL_REGRET_MSG'=>'Desculpe: Não é possível acessar a URL do RSS',

'UNABLE_TO_SAVE'=>'Impossível salvar URL do alimentador RSS',

// Added/Updated for vtiger CRM 5.0.4
'NOT_A_VALID'=>'URL inválida para alimentador RSS ou as configurações do seu Proxy não estão corretas',

// Added after 5.0.4 GA
'INVALID_RSS_URL' => 'URL RSS não é válida',
'UNABLE_TO_SAVE' => 'Não é possível salvar a URL',

);
?>
